==> hexo-theme-keep-4.1.1.tgz: package/docs/README_zh-CN.md <==
<div align="right">
  语言：
  简体中文 | 
  <a title="English" href="../README.md">English</a> | 
  <a title="繁體中文" href="README_zh-TW.md">繁體中文</a>
</div>
<a href="https://xpoet.cn"><img align="center" alt="Keep" src="https://keep-docs.xpoet.cn/images/keep-slogan.svg"></a>

# hexo-theme-keep

**Keep** 是一款简约轻快的 [Hexo](https://hexo.io) 主题。它能让你更专注于写作。

[![Github License](https://img.shields.io/github/license/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=3366cc)](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)
[![Github Release](https://img.shields.io/github/release/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=mediumpurple)](https://github.com/XPoet/hexo-theme-ils/releases)
[![NPM Version](https://img.shields.io/npm/v/hexo-theme-keep?style=flat-square&logo=npm&color=indianred)](https://www.npmjs.com/package/hexo-theme-keep)
[![NPM Downloads](https://img.shields.io/npm/dw/hexo-theme-keep?style=flat-square&logo=npm&color=darkorange)](https://www.npmjs.com/package/hexo-theme-keep)
[![Node.js Version](https://img.shields.io/badge/node-%3E=14.0.0-forestgreen?style=flat-square&logo=Node.js)](https://nodejs.org)
[![Required Hexo version](https://img.shields.io/badge/hexo-%3E=5.0.0-steelblue?style=flat-square&logo=hexo)](https://hexo.io)

## :star2: 在线预览

- **[XPoet's Blog](https://xpoet.cn/)**
- **[keep 演示](https://keep.xpoet.cn/)**

> 如果你想把自己的博客链接放置在线预览列表里，可以给作者提 PR。

## :books: 文档

请查看 **Keep** 官方文档：

- **[Keep 官方文档](https://keep-docs.xpoet.cn/)**
- **[Keep 主题配置指南](https://keep-docs.xpoet.cn/basis/configuration-guide/base_info.html)**
- **[Keep 主题进阶使用](https://keep-docs.xpoet.cn/advanced/set-language.html)**

## :rocket: 安装

如果你使用 Hexo 5.0 或更高版本，最简单的安装方式是通过 NPM：

```sh
# 推荐

cd your-hexo
npm install hexo-theme-keep
```

你也可以直接克隆整个仓库：

```sh
cd your-hexo
git clone https://github.com/XPoet/hexo-theme-keep --depth=1 themes/keep
```

安装完成后，在 Hexo 配置文件中将 `theme` 设置为 `keep`。

```yml
theme: keep
```

## :tada: 更新

**Keep** 不定期发布新版本，你可以通过如下命令更新 **Keep**。

通过 NPM 安装最新版本：

```sh
# 推荐

$ cd your-hexo
$ npm install hexo-theme-keep@latest
```

或者通过 git 更新到最新的 master 分支：

```sh
$ cd themes/keep
$ git pull
```

不推荐直接修改 **Keep** 主题的源文件。因为这可能导致错误（例如 git merge 冲突），并且在升级主题时修改的文件可能丢失。

## :art: 贡献者

这个项目的存在多亏了所有的贡献者。

<a href="https://github.com/XPoet/hexo-theme-keep/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=XPoet/hexo-theme-keep" />
</a>

我们欢迎你加入 **Keep** 的开发，贡献出你的一份力量。请看 [Keep 代码贡献指南](https://keep-docs.xpoet.cn/user-notice/contribution-guide.html)。

## :sparkling_heart: 鸣谢

**Keep** 特别感谢这些支持我们核心基础设施的优质服务：

- [GitHub](https://github.com) 容许我们托管 Git 仓库及运行测试。
- [cdnjs](https://cdnjs.com)、[jsDelivr](https://www.jsdelivr.com) 和 [UNPKG](https://www.unpkg.com) 提供了 CDN 服务。

## :memo: 许可

[AGPL-3.0](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)  

Copyright © 2020-present XPoet

==> hexo-theme-keep-4.2.5.tgz: package/docs/README_zh-CN.md <==
<div align="right">
  语言：
  简体中文 | 
  <a title="English" href="../README.md">English</a> | 
  <a title="繁體中文" href="README_zh-TW.md">繁體中文</a>
</div>
<a href="https://xpoet.cn"><img align="center" alt="Keep" src="https://keep-docs.xpoet.cn/images/keep-slogan.svg"></a>

# hexo-theme-keep

**Keep** 是一款简约轻快的 [Hexo](https://hexo.io) 主题，它能让你更专注于写作。

[![Github License](https://img.shields.io/github/license/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=3366cc)](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)
[![Github Release](https://img.shields.io/github/release/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=mediumpurple)](https://github.com/XPoet/hexo-theme-ils/releases)
[![NPM Version](https://img.shields.io/npm/v/hexo-theme-keep?style=flat-square&logo=npm&color=indianred)](https://www.npmjs.com/package/hexo-theme-keep)
[![NPM Downloads](https://img.shields.io/npm/dw/hexo-theme-keep?style=flat-square&logo=npm&color=darkorange)](https://www.npmjs.com/package/hexo-theme-keep)
[![Node.js Version](https://img.shields.io/badge/node-%3E=14.0.0-forestgreen?style=flat-square&logo=Node.js)](https://nodejs.org)
[![Required Hexo version](https://img.shields.io/badge/hexo-%3E=5.0.0-steelblue?style=flat-square&logo=hexo)](https://hexo.io)

## :star2: 在线预览

- **[XPoet's Blog](https://xpoet.cn/)**
- **[keep 演示](https://keep.xpoet.cn/)**

> 如果你想把自己的博客链接放置在线预览列表里，可以给作者提 PR。

## :books: 文档

请查看 **Keep** 官方文档：

- **[Keep 官方文档](https://keep-docs.xpoet.cn/)**
- **[Keep 主题配置指南](https://keep-docs.xpoet.cn/basis/configuration-guide/base_info.html)**
- **[Keep 主题进阶使用](https://keep-docs.xpoet.cn/advanced/set-language.html)**

## :rocket: 安装

如果你使用 Hexo 5.0 或更高版本，最简单的安装方式是通过 NPM：

```sh
# 推荐

cd your-hexo
npm install hexo-theme-keep
```

你也可以直接克隆整个仓库：

```sh
cd your-hexo
git clone https://github.com/XPoet/hexo-theme-keep --depth=1 themes/keep
```

安装完成后，在 Hexo 配置文件中将 `theme` 设置为 `keep`。

```yml
theme: keep
```

## :tada: 更新

**Keep** 不定期发布新版本，你可以通过如下命令更新 **Keep**。

通过 NPM 安装最新版本：

```sh
# 推荐

$ cd your-hexo
$ npm install hexo-theme-keep@latest
```

或者通过 git 更新到最新的 master 分支：

```sh
$ cd themes/keep
$ git pull
```

不推荐直接修改 **Keep** 主题的源文件。因为这可能导致错误（例如 git merge 冲突），并且在升级主题时修改的文件可能丢失。

## :art: 贡献者

这个项目的存在多亏了所有的贡献者。

<a href="https://github.com/XPoet/hexo-theme-keep/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=XPoet/hexo-theme-keep" />
</a>

我们欢迎你加入 **Keep** 的开发，贡献出你的一份力量。请看 [Keep 代码贡献指南](https://keep-docs.xpoet.cn/user-notice/contribution-guide.html)。

## :sparkling_heart: 鸣谢

**Keep** 特别感谢这些支持我们核心基础设施的优质服务：

- [GitHub](https://github.com) 容许我们托管 Git 仓库及运行测试。
- [cdnjs](https://cdnjs.com)、[jsDelivr](https://www.jsdelivr.com) 和 [UNPKG](https://www.unpkg.com) 提供了 CDN 服务。

## :memo: 许可

[AGPL-3.0](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)  

Copyright © 2020-present XPoet
